Improve this doc

# `ngRoute`

# ngRoute

The `ngRoute` module provides routing and deeplinking services and directives for angular apps.

## Example

See $route for an example of configuring and using `ngRoute`.

## Installation

First include `angular-route.js` in your HTML:

        <script src="angular.js">
        <script src="angular-route.js">

You can download this file from the following places:

- Google CDN
  e.g. `//ajax.googleapis.com/ajax/libs/angularjs/X.Y.Z/angular-route.js`
- Bower
  e.g.

      bower install angular-route@X.Y.Z

- code.angularjs.org
  e.g.

      "//code.angularjs.org/X.Y.Z/angular-route.js"

where X.Y.Z is the AngularJS version you are running.

Then load the module in your application by adding it as a dependent module:

      angular.module('app', ['ngRoute']);

With that you're ready to get started!

## Module Components

### Directive

Name | Description
--- | ---
ngView | # Overview `ngView` is a directive that complements the $route service by including the rendered template of the current route into the main layout (`index.html`) file. Every time the current route changes, the included view changes with it according to the configuration of the `$route` service.

### Provider

Name | Description
--- | ---
$routeProvider | Used for configuring routes.

### Service

Name | Description
--- | ---
$route | `$route` is used for deep-linking URLs to controllers and views (HTML partials). It watches `$location.url()` and tries to map the path to an existing route definition.
$routeParams | The `$routeParams` service allows you to retrieve the current set of route parameters.